#  tests for msinttypes-r26-h7e1a5f4_2 (this is a generated file);
print('===== testing package: msinttypes-r26-h7e1a5f4_2 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys

inc = os.path.join(sys.prefix, 'Library', 'include')
assert os.path.isfile(os.path.join(inc, 'stdint.h'))
assert os.path.isfile(os.path.join(inc, 'inttypes.h'))
#  --- run_test.py (end) ---

print('===== msinttypes-r26-h7e1a5f4_2 OK =====');
